# -*- coding: utf-8 -*-
#
# Copyright (c) 2008 by Intevation GmbH
#
# FormEd is free software under the terms of the
# GNU General Public License Version 3. See file
# LICENSE coming with the source of kowitest for details.
#
# Authors:
# Sascha L. Teichmann <teichmann@intevation.de>
#

from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler
from cgi            import parse_qs

import codecs
import re
import traceback

ACTION = re.compile(r".*?([-a-zA-Z0-9_]*)$")

NOT_FOUND = """
<html>
    <body>
        <center><h2>404 - Not Found!</h2></center>
    </body>
</html>

"""
INTERNAL_ERROR = """
<html>
    <body>
        <center><h2>500 - Internal Server Error</h2></center>
    </body>
</html>
"""

class MyHTTPServer(HTTPServer):

    def __init__(self, serverAddress, handlers = {}):
        HTTPServer.__init__(self, serverAddress, MyRequestHandler)
        self.handlers = handlers
        self.sessions = {}

    def addMapping(self, action, handler):
        self.handlers[action] = handler

    def dispatch(self, path, params):
        m = ACTION.match(path)

        if not m:
            return Response(NOT_FOUND, response=404)

        try:
            handler = self.handlers[m.group(1)]
        except KeyError:
            return Response(NOT_FOUND, response=404)

        try:
            return handler(path, params)
        except:
            traceback.print_exc()
            return Response(INTERNAL_ERROR, response=500)

class Response:
    def __init__(self, data=None, mime="text/html", 
        encoding="UTF-8", response=200):
        self.mime     = mime
        self.data     = data
        self.encoding = encoding
        self.response = response

class MyRequestHandler(BaseHTTPRequestHandler):

    def _queryString(self):
        path = self.path
        idx = path.find('?')
        if idx < 0: return path, {}
        uni = {}
        for k, v in parse_qs(path[idx+1:], keep_blank_values=True).iteritems():
            uni[unicode(k, 'UTF-8')] = [unicode(s, 'UTF-8') for s in v]
        return path[0:idx], uni

    def _send(self, response):
        self.send_response(response.response)
        self.end_headers()
        if response.data:
            if response.encoding:
                writerClass = codecs.getwriter(response.encoding)
                stream = writerClass(self.wfile)
            else:
                stream = self.wfile

            stream.write(response.data)

    # XXX: This is not thread safe!
    def do_GET(self):
        if self.path.endswith("favicon.ico"):
            self.send_error(404)
            return
        path, params = self._queryString()
        self._send(self.server.dispatch(path, params))

# vim:set ts=4 sw=4 si et sta sts=4:
