<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output 
        encoding="UTF-8" 
        method="html"
        doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
        doctype-public="-//W3C//DTD HTML 4.01//EN" />

    <xsl:param name="selected-suite"/>

    <xsl:template name="test-checkbox">
        <xsl:param name="test-num"/>  
        <xsl:param name="result-num"/>  
        <xsl:param name="value"/>  
        <xsl:param name="desc"/>  
        <TT>[<A><xsl:attribute name="HREF">
                <xsl:text>set-test?suite=</xsl:text>
                <xsl:value-of select="$selected-suite"/>
                <xsl:text>&amp;test=</xsl:text>
                <xsl:value-of select="$test-num"/>
                <xsl:text>&amp;result=</xsl:text>
                <xsl:value-of select="$result-num"/>
                <xsl:text>&amp;value=</xsl:text>
                <xsl:value-of select="$value"/>
                <xsl:text>#test</xsl:text>
                <xsl:value-of select="$test-num"/>
                <xsl:text>-</xsl:text>
                <xsl:value-of select="$result-num"/>
            </xsl:attribute><xsl:text disable-output-escaping="yes"><![CDATA[&#160;]]></xsl:text></A>]</TT>
        <SUB><xsl:value-of select="$desc"/></SUB>
        <xsl:text> </xsl:text>
    </xsl:template>

    <xsl:template match="step" mode="steps">
        <LI><xsl:value-of select="."/></LI>
    </xsl:template>

    <xsl:template match="script" mode="steps">
        <xsl:variable name="test-number" 
            select="count(../../preceding-sibling::*[name() = 'test'])"/>

        <xsl:variable name="script-number" 
            select="count(preceding-sibling::*[name() = 'script'])"/>

        <LI><xsl:value-of select="@description"/> 
            [<A><xsl:attribute name="HREF">
                    <xsl:text>execute?suite=</xsl:text>
                    <xsl:value-of select="$selected-suite"/>
                    <xsl:text>&amp;test=</xsl:text>
                    <xsl:value-of select="$test-number"/>
                    <xsl:text>&amp;script=</xsl:text>
                    <xsl:value-of select="$script-number"/>
                </xsl:attribute>Execute!</A>]
        </LI>
    </xsl:template>

    <xsl:template match="result" mode="results">

        <xsl:variable name="test-number" 
            select="count(../../preceding-sibling::*[name() = 'test'])"/>

        <xsl:variable name="result-number" 
            select="count(preceding-sibling::*[name() = 'result'])"/>

        <LI><A NAME="test{$test-number}-{$result-number}"><xsl:value-of select="."/><xsl:text> </xsl:text></A>
            <xsl:choose>
                <xsl:when test="@value = 'passed'">
                    <TT>[X]<SUB>yes</SUB></TT>
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value">failed</xsl:with-param>
                        <xsl:with-param name="desc">no</xsl:with-param>
                    </xsl:call-template>
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value"/>
                        <xsl:with-param name="desc">N/A</xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value = 'failed'">
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value">passed</xsl:with-param>
                        <xsl:with-param name="desc">yes</xsl:with-param>
                    </xsl:call-template>
                    <TT>[X]<SUB>no</SUB></TT>
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value"/>
                        <xsl:with-param name="desc">N/A</xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value">passed</xsl:with-param>
                        <xsl:with-param name="desc">yes</xsl:with-param>
                    </xsl:call-template>
                    <xsl:call-template name="test-checkbox">
                        <xsl:with-param name="test-num" select="$test-number"/>
                        <xsl:with-param name="result-num" select="$result-number"/>
                        <xsl:with-param name="value">failed</xsl:with-param>
                        <xsl:with-param name="desc">no</xsl:with-param>
                    </xsl:call-template>
                    <TT>[X]<SUB>N/A</SUB></TT>
                </xsl:otherwise>
            </xsl:choose>
        </LI>
    </xsl:template>

    <xsl:template match="test" mode="tests">
        <xsl:variable name="suite-number" 
            select="count(../preceding-sibling::*[name() = 'testsuite']) + 1"/>

        <xsl:variable name="test-number" 
            select="count(preceding-sibling::*[name() = 'test']) + 1"/>

        <DIV>
            <H4><xsl:value-of select="$suite-number"/>.<xsl:value-of select="$test-number"/>
                <xsl:text> </xsl:text><xsl:value-of select="@description"/></H4>

            <H4>Precondition: <xsl:value-of select="preceding"/></H4>

            <DIV>
                <H4>Steps:</H4>
                <OL>
                    <xsl:apply-templates mode="steps"/>
                </OL>
            </DIV>

            <DIV>
                <H4>Expected Results:</H4>
                <OL type="a">
                    <xsl:apply-templates mode="results"/>
                </OL>
            </DIV>
        </DIV>
    </xsl:template>

    <xsl:template match="testsuite" mode="testsuite">

        <xsl:variable name="suite-number" select="count(preceding-sibling::*[name() = 'testsuite']) + 1"/>

        <H2>Test suite <xsl:value-of select="$suite-number"/>:
        <xsl:value-of select="@description"/></H2>

        <H3>General Precondition:</H3>
        <P><xsl:value-of select="./general-precondition"/></P>

        <DIV>
            <xsl:apply-templates mode="tests"/>
        </DIV>
    </xsl:template>

    <xsl:template match="testsuite">
        <xsl:if test="$selected-suite = @id">
            <xsl:apply-templates select="." mode="testsuite"/>
        </xsl:if>
    </xsl:template>

    <xsl:template match="testplan">
        <HTML>
            <HEAD>
                <!--
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
                -->
                <TITLE>Test plan for <xsl:value-of select="./meta/product-name"/></TITLE>
            </HEAD>
            <BODY>
                Actions: [<A HREF="index">Back to overview</A>] [<A HREF="quit">Quit</A>]<BR/>
                <xsl:apply-templates/>
            </BODY>
        </HTML>
    </xsl:template>

    <xsl:template match="text()"/>
    <xsl:template match="text()" mode="testsuite"/>
    <xsl:template match="text()" mode="tests"/>
    <xsl:template match="text()" mode="steps"/>
    <xsl:template match="text()" mode="results"/>

</xsl:stylesheet>
